import 'package:rec_api_dart/src/env.base.dart';
import 'package:rec_api_dart/src/helpers/strings.dart';

class ApiPath {
  final String path;
  final Map<String, dynamic>? queryParams;

  ApiPath(this.path, [this.queryParams]);

  /// Returns a new [ApiPath] with the provided params set
  ApiPath withQueryParams(Map<String, dynamic>? params) {
    return ApiPath(path, params);
  }

  /// Returns a new [ApiPath] with the provided params interpolated in the current path
  ApiPath withParams(Map<String, dynamic> params) {
    return ApiPath(
      Strings.interpolate(path, params: params),
      queryParams,
    );
  }

  /// Returns a new ApiPath with a path segment appended to the path
  /// of the original ApiPath
  ///
  /// NOTE: Don't include the `/`, this is added automatically
  ApiPath append(String? suffix) {
    return ApiPath('$path/$suffix', queryParams);
  }

  /// Returns a new ApiPath with a list of path segments appended to the path
  /// of the original ApiPath
  ApiPath appendMultiple(List<String?> suffixes) {
    return ApiPath('$path/${suffixes.join('/')}', queryParams);
  }

  /// Deprecated, prefer using [asUri] instead
  @Deprecated("Deprecated in favor of [ApiPath.asUri(String authority)]")
  Uri toUri(EnvBase env) {
    return Uri.https(
      env.API_URL,
      path,
      queryParams,
    );
  }

  /// Return a [Uri] class instance, for this API path. You only need to specify the authority
  Uri asUri(String authority) {
    return Uri.https(
      authority,
      path,
      queryParams,
    );
  }
}
