import 'package:rec_api_dart/src/entities/account.ent.dart';
import 'package:rec_api_dart/src/mixins/account_type.mixin.dart';
import 'package:rec_api_dart/src/entities/dto/form_data.dart';

class RegisterData extends FormData with AccountType {
  String? dni;
  String? password;
  String? prefix;
  String? phone;

  @override
  String? accountType;

  bool? termsAccepted = false;

  // Only if type COMPANY
  String? companyName;
  String? companyCif;

  /// Specifies the platform from which the register is being made
  /// This is not required
  String? platform;

  // Only for rezero b2b
  String? rezeroB2BUsername;

  RegisterData({
    required this.accountType,
    this.dni,
    this.password,
    this.prefix,
    this.phone,
    this.companyName,
    this.companyCif,
    this.rezeroB2BUsername,
    this.platform,
    this.termsAccepted = false,
  });

  @override
  Map<String, dynamic> toJson() {
    var data = {
      'dni': dni,
      'password': password,
      'prefix': prefix,
      'phone': phone,
    };

    if (accountType == Account.TYPE_PRIVATE) {
      return data;
    }

    if (rezeroB2BUsername != null && rezeroB2BUsername!.isNotEmpty) {
      data['rezero_b2b_username'] = rezeroB2BUsername;
    }


    if (platform != null && platform!.isNotEmpty) {
      data['platform'] = platform;
    }

    return {
      ...data,
      'company_name': companyName,
      'company_cif': companyCif,
    };
  }
}
