import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/annotations.dart';
import 'package:rec_api_dart/src/api_paths.dart';
import 'package:rec_api_dart/src/auth.dart';
import 'package:rec_api_dart/src/entities/dto/login_data.dart';
import 'package:rec_api_dart/src/services/public/login_service.dart';
import 'package:http/http.dart' as http;

import '../../http_stubs.dart';
import '../../mocks/storage_mock.dart';
import '../../test_env.dart';
import 'login_service.mocks.dart';

@GenerateMocks([http.Client])
void main() {
  final mockStorage = StorageMock();
  Auth.storage = mockStorage;

  testWidgets('LoginService.login calls correctly and returns', (c) async {
    final client = MockClient();
    stubPost(
      client,
      ApiPaths.token.asUri(env.API_URL),
      http.Response(
        '{"access_token": "test", "refresh_token": "test", "expires_in": 3600}',
        200,
      ),
    );

    final service = LoginService(
      env: env,
      client: client,
    );

    expect(
      await service.login(
        LoginData(
          username: 'manolo',
          password: 'test1234',
          version: 10,
        ),
      ),
      {"access_token": "test", "refresh_token": "test", "expires_in": 3600},
    );
  });

  testWidgets('LoginService.refreshToken calls correctly and returns', (c) async {
    final client = MockClient();
    stubPost(
      client,
      ApiPaths.refreshToken.asUri(env.API_URL),
      http.Response(
        '{"access_token": "test", "refresh_token": "test", "expires_in": 3600}',
        200,
      ),
    );

    final service = LoginService(
      env: env,
      client: client,
    );

    expect(
      await service.refreshToken('old_token'),
      {"access_token": "test", "refresh_token": "test", "expires_in": 3600},
    );
  });
}
